==> rpm-4.0.2-i386-6.tgz: install/doinst.sh <==
if [ ! -r var/lib/rpm/Packages ]; then
  ( cd var/lib/rpm/tmp ; cp -a * .. )
fi
( cd var/lib/rpm && rm -f tmp/* && rmdir tmp )
# Symlinks:
( cd usr/bin ; rm -rf rpme )
( cd usr/bin ; ln -sf ../lib/rpm/rpme rpme )
( cd usr/bin ; rm -rf rpmi )
( cd usr/bin ; ln -sf ../lib/rpm/rpmi rpmi )
( cd usr/bin ; rm -rf rpmu )
( cd usr/bin ; ln -sf ../lib/rpm/rpmu rpmu )
( cd usr/bin ; rm -rf rpmdb )
( cd usr/bin ; ln -sf ../lib/rpm/rpmdb rpmdb )
( cd usr/bin ; rm -rf rpmsign )
( cd usr/bin ; ln -sf ../lib/rpm/rpmk rpmsign )
( cd usr/bin ; rm -rf rpmverify )
( cd usr/bin ; ln -sf ../lib/rpm/rpmv rpmverify )
( cd usr/bin ; rm -rf rpmbuild )
( cd usr/bin ; ln -sf ../lib/rpm/rpmb rpmbuild )
( cd usr/bin ; rm -rf rpmquery )
( cd usr/bin ; ln -sf ../lib/rpm/rpmq rpmquery )
( cd usr/lib/rpm ; rm -rf rpme )
( cd usr/lib/rpm ; ln -sf rpmi rpme )
( cd usr/lib/rpm ; rm -rf rpmt )
( cd usr/lib/rpm ; ln -sf rpmb rpmt )
( cd usr/lib/rpm ; rm -rf rpmu )
( cd usr/lib/rpm ; ln -sf rpmi rpmu )
( cd usr/lib/rpm ; rm -rf rpmv )
( cd usr/lib/rpm ; ln -sf rpmq rpmv )
( cd usr/lib/rpm ; rm -rf i386-linux )
( cd usr/lib/rpm ; ln -sf i386-rpm-linux i386-linux )
( cd usr/lib/rpm ; rm -rf rpmpopt )
( cd usr/lib/rpm ; ln -sf rpmpopt-4.0.2 rpmpopt )
( cd usr/lib/rpm ; rm -rf i586-linux )
( cd usr/lib/rpm ; ln -sf i586-rpm-linux i586-linux )
( cd usr/lib/rpm ; rm -rf noarch-rpm-linux )
( cd usr/lib/rpm ; ln -sf i386-rpm-linux noarch-rpm-linux )
( cd usr/lib/rpm ; rm -rf i486-linux )
( cd usr/lib/rpm ; ln -sf i486-rpm-linux i486-linux )
( cd usr/lib/rpm ; rm -rf noarch-linux )
( cd usr/lib/rpm ; ln -sf i386-rpm-linux noarch-linux )
( cd usr/lib/rpm ; rm -rf i686-linux )
( cd usr/lib/rpm ; ln -sf i686-rpm-linux i686-linux )
( cd usr/lib ; rm -rf librpmio.so.0 )
( cd usr/lib ; ln -sf librpmio.so.0.0.0 librpmio.so.0 )
( cd usr/lib ; rm -rf rpmrc )
( cd usr/lib ; ln -sf rpm/rpmrc rpmrc )
( cd usr/lib ; rm -rf librpm.so )
( cd usr/lib ; ln -sf librpm.so.0.0.0 librpm.so )
( cd usr/lib ; rm -rf rpmpopt )
( cd usr/lib ; ln -sf rpm/rpmpopt rpmpopt )
( cd usr/lib ; rm -rf librpm.so.0 )
( cd usr/lib ; ln -sf librpm.so.0.0.0 librpm.so.0 )
( cd usr/lib ; rm -rf librpmio.so )
( cd usr/lib ; ln -sf librpmio.so.0.0.0 librpmio.so )
( cd usr/lib ; rm -rf librpmbuild.so )
( cd usr/lib ; ln -sf librpmbuild.so.0.0.0 librpmbuild.so )
( cd usr/lib ; rm -rf librpmbuild.so.0 )
( cd usr/lib ; ln -sf librpmbuild.so.0.0.0 librpmbuild.so.0 )

==> rpm-4.2.1-i486-2.tgz: install/doinst.sh <==
if [ ! -r var/lib/rpm/Packages ]; then
  ( cd var/lib/rpm/tmp ; cp -a * .. )
fi
( cd var/lib/rpm && rm -f tmp/* && rmdir tmp )
# Symlinks:
( cd usr/bin ; rm -rf rpme )
( cd usr/bin ; ln -sf ../lib/rpm/rpme rpme )
( cd usr/bin ; rm -rf rpmi )
( cd usr/bin ; ln -sf ../lib/rpm/rpmi rpmi )
( cd usr/bin ; rm -rf rpmu )
( cd usr/bin ; ln -sf ../lib/rpm/rpmu rpmu )
( cd usr/bin ; rm -rf rpmdb )
( cd usr/bin ; ln -sf ../lib/rpm/rpmd rpmdb )
( cd usr/bin ; rm -rf rpmsign )
( cd usr/bin ; ln -sf ../lib/rpm/rpmk rpmsign )
( cd usr/bin ; rm -rf rpmverify )
( cd usr/bin ; ln -sf ../lib/rpm/rpmv rpmverify )
( cd usr/bin ; rm -rf rpmbuild )
( cd usr/bin ; ln -sf ../lib/rpm/rpmb rpmbuild )
( cd usr/bin ; rm -rf rpmquery )
( cd usr/bin ; ln -sf ../lib/rpm/rpmq rpmquery )
( cd usr/lib/rpm ; rm -rf rpme )
( cd usr/lib/rpm ; ln -sf rpmi rpme )
( cd usr/lib/rpm ; rm -rf rpmt )
( cd usr/lib/rpm ; ln -sf rpmb rpmt )
( cd usr/lib/rpm ; rm -rf rpmu )
( cd usr/lib/rpm ; ln -sf rpmi rpmu )
( cd usr/lib/rpm ; rm -rf rpmv )
( cd usr/lib/rpm ; ln -sf rpmq rpmv )
( cd usr/lib ; rm -rf rpmrc )
( cd usr/lib ; ln -sf rpm/rpmrc rpmrc )
( cd usr/lib ; rm -rf librpm.so )
( cd usr/lib ; ln -sf librpm-4.2.so librpm.so )
( cd usr/lib ; rm -rf rpmpopt )
( cd usr/lib ; ln -sf rpm/rpmpopt rpmpopt )
( cd usr/lib ; rm -rf librpmdb.so )
( cd usr/lib ; ln -sf librpmdb-4.2.so librpmdb.so )
( cd usr/lib ; rm -rf librpmio.so )
( cd usr/lib ; ln -sf librpmio-4.2.so librpmio.so )
( cd usr/lib ; rm -rf librpmbuild.so )
( cd usr/lib ; ln -sf librpmbuild-4.2.so librpmbuild.so )
